Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

FeedforwardClosedloopLearningWithFilterbank Member List

This is the complete list of members for FeedforwardClosedloopLearningWithFilterbank, including all inherited members.

doStep(double *input, double *error) | FeedforwardClosedloopLearningWithFilterbank |
doStep(double *input, int n1, double *error, int n2) | FeedforwardClosedloopLearningWithFilterbank |
FeedforwardClosedloopLearning(int num_of_inputs, int *num_of_neurons_per_layer_array, int _num_layers) | FeedforwardClosedloopLearning |
FeedforwardClosedloopLearningWithFilterbank(int num_of_inputs, int *num_of_neurons_per_layer_array, int num_layers, int num_filtersInput, double minT, double maxT) | FeedforwardClosedloopLearningWithFilterbank |
getFilterOutput(int inputIdx, int filterIdx) (defined in FeedforwardClosedloopLearningWithFilterbank) | FeedforwardClosedloopLearningWithFilterbank | inline
getLayer(int i) | FeedforwardClosedloopLearning | inline
getLayers() | FeedforwardClosedloopLearning | inline
getNFiltersPerInput() (defined in FeedforwardClosedloopLearningWithFilterbank) | FeedforwardClosedloopLearningWithFilterbank | inline
getNumInputs() | FeedforwardClosedloopLearning | inline
getNumLayers() | FeedforwardClosedloopLearning | inline
getOutput(int index) | FeedforwardClosedloopLearning | inline
getOutputLayer() | FeedforwardClosedloopLearning | inline
initWeights(double max=0.001, int initBias=1, Neuron::WeightInitMethod weightInitMethod=Neuron::MAX_OUTPUT_RANDOM) | FeedforwardClosedloopLearning |
loadModel(const char *name) | FeedforwardClosedloopLearning |
saveModel(const char *name) | FeedforwardClosedloopLearning |
seedRandom(int s) | FeedforwardClosedloopLearning | inline
setActivationFunction(Neuron::ActivationFunction _activationFunction) | FeedforwardClosedloopLearning |
setBias(double _bias) | FeedforwardClosedloopLearning |
setDecay(double decay) | FeedforwardClosedloopLearning |
setLearningRate(double learningRate) | FeedforwardClosedloopLearning |
setLearningRateDiscountFactor(double _learningRateDiscountFactor) | FeedforwardClosedloopLearning | inline
setMomentum(double momentum) | FeedforwardClosedloopLearning |
~FeedforwardClosedloopLearning() | FeedforwardClosedloopLearning |
~FeedforwardClosedloopLearningWithFilterbank() | FeedforwardClosedloopLearningWithFilterbank |